@@ -14,6 +14,7 @@ import logging
 import re
 from urllib.parse import urlparse
 
+
 # yaml 数据模型
 class YamlModuleModel:
     module = ''
@@ -1047,7 +1048,7 @@ class yhgit:
             logging.info(fail_module)
 
     # 获取podfileLocal.yaml中各模块状态, 提示： 1. 很干净没有未提交的代码 2. 有改动未提交 3. 没有相关文件报错误
-    def   status(self):
+    def status(self):
         """
         获取podfileLocal.yaml中各模块状态, 提示： 1. 很干净没有未提交的代码 2. 有改动未提交
         1. 如果podfileLocal.yaml是空则终止
@@ -1055,7 +1056,7 @@ class yhgit:
         :return:
         """
         modules_file_name = "modules"
-        modules_path =  modules_file_name + "/"
+        modules_path = modules_file_name + "/"
         local_yaml_path = 'PodfileLocal.yaml'
 
         # 子目录，用来存放子模块仓库, 如果没有需要创建一个
@@ -1310,31 +1311,14 @@ def debugInfo(msg):
     print(msg)
 
 
-if __name__ == '__main__':
-    cuPath = os.getcwd()
-    # fa_path = "../../Desktop/Project/yh-rme-srm-purchase-ios/"
-    # project_git = "http://gitlab.yonghui.cn/operation-pc-mid-p/yh-rme-srm-purchase-ios.git"
-    # # 分支的名字，如果没有指定将用年月日表示
-    # n_branch = "221107"
+def main(argvs=None):
+    """The main routine."""
 
-    # cb = yhmgit(git=project_git, path=fa_path, n_branch=n_branch)
-    # cb.init_project(clean_proj=False)
-    # cb.pull_modules()
-    # cb.push_modules()
-    # cb.merge_modules()
-    # os.chdir(fa_path)
-    # os.system("pod install")
-
-    """
-    argv[0]:  获取命令的类型 如下
-    install  
-
-    argv[1]:  命令的
-
-
-    """
+    # Do argument parsing here (eg. with argparse) and anything else
+    # you want your project to do.
     # 获取参数
-    argvs = sys.argv
+    if argvs is None:
+        argvs = sys.argv
     print(argvs)
     # 获取指令类型
     command = argvs[0]
@@ -1397,3 +1381,29 @@ if __name__ == '__main__':
 
     elif command == "clean":
         yhgit().clean()
+
+
+if __name__ == '__main__':
+    cuPath = os.getcwd()
+    main()
+    # fa_path = "../../Desktop/Project/yh-rme-srm-purchase-ios/"
+    # project_git = "http://gitlab.yonghui.cn/operation-pc-mid-p/yh-rme-srm-purchase-ios.git"
+    # # 分支的名字，如果没有指定将用年月日表示
+    # n_branch = "221107"
+
+    # cb = yhmgit(git=project_git, path=fa_path, n_branch=n_branch)
+    # cb.init_project(clean_proj=False)
+    # cb.pull_modules()
+    # cb.push_modules()
+    # cb.merge_modules()
+    # os.chdir(fa_path)
+    # os.system("pod install")
+
+    """
+    argv[0]:  获取命令的类型 如下
+    install  
+
+    argv[1]:  命令的
+
+
+    """
